"use strict";
///<reference path="../typings/index.d.ts" />
var test = require('tape');
var _1 = require('./');
function createObject(object) {
    var obj = {
        undo: function () {
            object.undoCount++;
            return true;
        },
        redo: function () {
            object.redoCount++;
            return true;
        }
    };
    return obj;
}
function undo(undoRedo, numTimes) {
    if (numTimes === void 0) { numTimes = 1; }
    for (var i = 0; i < numTimes; i++) {
        undoRedo.doUndo();
    }
}
function redo(undoRedo, numTimes) {
    if (numTimes === void 0) { numTimes = 1; }
    for (var i = 0; i < numTimes; i++) {
        undoRedo.doRedo();
    }
}
function addUndo(undoRedo, obj, numTimes) {
    if (numTimes === void 0) { numTimes = 1; }
    for (var i = 0; i < numTimes; i++) {
        undoRedo.addUndoObject(obj);
    }
}
test("should call both doUndo() and doRedo() 1 time", function (t) {
    var undoRedoStack = new _1.default();
    var countObj = {
        undoCount: 0,
        redoCount: 0
    };
    addUndo(undoRedoStack, createObject(countObj));
    undo(undoRedoStack);
    redo(undoRedoStack);
    t.equal(countObj.undoCount, 1);
    t.equal(countObj.redoCount, 1);
    t.end();
});
test("should call doUndo() 3 times and doRedo() 1 time", function (t) {
    var undoRedoStack = new _1.default();
    var countObj = {
        undoCount: 0,
        redoCount: 0
    };
    var obj = createObject(countObj);
    addUndo(undoRedoStack, obj, 3);
    undo(undoRedoStack, 3);
    redo(undoRedoStack);
    t.equal(countObj.undoCount, 3);
    t.equal(countObj.redoCount, 1);
    t.end();
});
test("should successfully call doUndo() 3 times even though it is called 4 times", function (t) {
    var undoRedoStack = new _1.default();
    var countObj = {
        undoCount: 0,
        redoCount: 0
    };
    var obj = createObject(countObj);
    addUndo(undoRedoStack, obj, 3);
    undo(undoRedoStack, 4);
    t.equal(countObj.undoCount, 3);
    t.end();
});
test("should call doUndo() and doRedo() 0 times because nothing added to stacks at the start", function (t) {
    var undoRedoStack = new _1.default();
    var countObj = {
        undoCount: 0,
        redoCount: 0
    };
    undo(undoRedoStack, 4);
    redo(undoRedoStack, 2);
    t.equal(countObj.undoCount, 0);
    t.equal(countObj.redoCount, 0);
    t.end();
});
test("should call doUndo() 4 times and doRedo() 3 times", function (t) {
    var undoRedoStack = new _1.default();
    var countObj = {
        undoCount: 0,
        redoCount: 0
    };
    var obj = createObject(countObj);
    addUndo(undoRedoStack, obj, 3);
    undo(undoRedoStack);
    redo(undoRedoStack, 2);
    undo(undoRedoStack, 3);
    redo(undoRedoStack, 2);
    t.equal(countObj.undoCount, 4);
    t.equal(countObj.redoCount, 3);
    t.end();
});
test("should call doUndo() and doRedo() 0 times since function added is called first", function (t) {
    var undoRedoStack = new _1.default();
    var countObj = {
        undoCount: 0,
        redoCount: 0
    };
    var obj = createObject(countObj);
    var func = undoRedoStack.addUndoObject(obj);
    func();
    undo(undoRedoStack);
    redo(undoRedoStack);
    t.equal(countObj.undoCount, 0);
    t.equal(countObj.redoCount, 0);
    t.end();
});
//# sourceMappingURL=UndoRedo.spec.js.map