///<reference path="../typings/index.d.ts" />
"use strict";
var UndoRedo = (function () {
    function UndoRedo() {
        this._undoStack = [];
        this._redoStack = [];
        this._Z_KEY = 90;
    }
    UndoRedo.prototype.doUndo = function () {
        if (!!this._undoStack.length) {
            var undoObj = this._undoStack.pop();
            if (undoObj.undo && undoObj.undo() !== false) {
                this._redoStack.push(undoObj);
            }
        }
    };
    UndoRedo.prototype.doRedo = function () {
        if (!!this._redoStack.length) {
            var undoObj = this._redoStack.pop();
            if (undoObj.redo && undoObj.redo() !== false) {
                this._undoStack.push(undoObj);
            }
        }
    };
    UndoRedo.prototype.make = function (element, preventKeys) {
        element.addEventListener('keydown', function (event) {
            if (preventKeys) {
                event.preventDefault();
                event.stopPropagation();
            }
            var key = event.keyCode || event.which;
            if (key === this._Z_KEY && (window.navigator.userAgent.match(/win/i) ? event.ctrlKey : event.metaKey)) {
                if (event.shiftKey) {
                    this.doRedo();
                }
                else {
                    this.doUndo();
                }
            }
        }.bind(this));
    };
    UndoRedo.prototype.addUndoObject = function (object) {
        var _this = this;
        this._redoStack = [];
        this._undoStack.push(object);
        return function () { return _this._removeUndoObject(object); };
    };
    UndoRedo.prototype._removeUndoObject = function (handler) {
        var undoIndex = this._undoStack.indexOf(handler);
        var redoIndex = this._redoStack.indexOf(handler);
        if (undoIndex !== -1) {
            this._undoStack.splice(undoIndex, 1);
        }
        if (redoIndex !== -1) {
            this._undoStack.splice(redoIndex, 1);
        }
    };
    UndoRedo.prototype.clear = function () {
        this._undoStack = [];
        this._redoStack = [];
    };
    return UndoRedo;
}());
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = UndoRedo;
//# sourceMappingURL=index.js.map